==> ant-design-vue-3.2.19.jar: META-INF/resources/webjars/ant-design-vue/3.2.19/lib/typography/Text.d.ts <==
import type { ExtractPropTypes, FunctionalComponent, PropType } from 'vue';
import type { EllipsisConfig } from './Base';
export declare const textProps: () => {
    ellipsis: {
        type: PropType<boolean | Omit<EllipsisConfig, "onExpand" | "expandable" | "rows">>;
        default: boolean | Omit<EllipsisConfig, "onExpand" | "expandable" | "rows">;
    };
    prefixCls: StringConstructor;
    code: {
        type: BooleanConstructor;
        default: any;
    };
    mark: {
        type: BooleanConstructor;
        default: any;
    };
    strong: {
        type: BooleanConstructor;
        default: any;
    };
    content: StringConstructor;
    underline: {
        type: BooleanConstructor;
        default: any;
    };
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    type: PropType<import("./Base").BaseType>;
    editable: {
        type: PropType<boolean | import("./Base").EditConfig>;
        default: boolean | import("./Base").EditConfig;
    };
    keyboard: {
        type: BooleanConstructor;
        default: any;
    };
    delete: {
        type: BooleanConstructor;
        default: any;
    };
    copyable: {
        type: PropType<boolean | import("./Base").CopyConfig>;
        default: boolean | import("./Base").CopyConfig;
    };
    'onUpdate:content': PropType<(content: string) => void>;
};
export declare type TextProps = Partial<ExtractPropTypes<ReturnType<typeof textProps>>>;
declare const Text: FunctionalComponent<TextProps>;
export default Text;

==> ant-design-vue-4.0.6.jar: META-INF/resources/webjars/ant-design-vue/4.0.6/lib/typography/Text.d.ts <==
import type { ExtractPropTypes, FunctionalComponent, PropType } from 'vue';
import type { EllipsisConfig } from './Base';
export declare const textProps: () => {
    ellipsis: {
        type: PropType<boolean | Omit<EllipsisConfig, "rows" | "onExpand" | "expandable">>;
        default: boolean | Omit<EllipsisConfig, "rows" | "onExpand" | "expandable">;
    };
    code: {
        type: BooleanConstructor;
        default: any;
    };
    mark: {
        type: BooleanConstructor;
        default: any;
    };
    strong: {
        type: BooleanConstructor;
        default: any;
    };
    content: StringConstructor;
    underline: {
        type: BooleanConstructor;
        default: any;
    };
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    type: PropType<import("./Base").BaseType>;
    prefixCls: StringConstructor;
    editable: {
        type: PropType<boolean | import("./Base").EditConfig>;
        default: boolean | import("./Base").EditConfig;
    };
    keyboard: {
        type: BooleanConstructor;
        default: any;
    };
    delete: {
        type: BooleanConstructor;
        default: any;
    };
    copyable: {
        type: PropType<boolean | import("./Base").CopyConfig>;
        default: boolean | import("./Base").CopyConfig;
    };
    'onUpdate:content': PropType<(content: string) => void>;
};
export type TextProps = Partial<ExtractPropTypes<ReturnType<typeof textProps>>>;
declare const Text: FunctionalComponent<TextProps>;
export default Text;
